import { HttpClient } from '@angular/common/http';
import { inject, Injectable } from '@angular/core';
import { Observable, shareReplay } from 'rxjs';
import { Hotel } from '../model/hotel';

@Injectable({
  providedIn: 'root',
})
export class HotelService {
  private httpClient: HttpClient = inject(HttpClient);

  public getHotels(): Observable<Hotel[]> {
    return this.httpClient.get<Hotel[]>('/api/hotels').pipe(shareReplay());
  }

  public getHotelById(id: number): Observable<Hotel> {
    return this.httpClient.get<Hotel>(`/api/hotels/${id}`).pipe(shareReplay());
  }

  public updateHotelById(hotel: Hotel): Observable<Object> {
    return this.httpClient.put<Hotel>(`/api/hotels/${hotel.id}`, hotel);
  }

  public createHotel(hotel: Hotel): Observable<Hotel> {
    return this.httpClient.post<Hotel>(`/api/hotels`, hotel);
  }

  public deleteById(id: number): Observable<Hotel> {
    return this.httpClient.delete<Hotel>(`/api/hotels/${id}`);
  }
}
